/******************************************************************************/
/* RTE - CMSIS Run-Time Environment */
/******************************************************************************/
/** @file RteCallback.cpp
* @brief CMSIS RTE Data Model
*/
/******************************************************************************/
/*
 * Copyright (c) 2020-2021 Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 */
/******************************************************************************/
#include "RteCallback.h"

#include "RteKernel.h"
#include "RteProject.h"
#include "RteTarget.h"
#include "RteBoard.h"

#include "RteUtils.h"

using namespace std;

RteCallback* RteCallback::theGlobalCallback = nullptr;

RteCallback::RteCallback():
m_rteKernel(nullptr)
{

}


void RteCallback::OutputMessages(const std::list<string>& messages)
{
    for (std::list<string>::const_iterator it = messages.begin(); it != messages.end(); it++) {
      OutputMessage(*it);
    }
};

long RteCallback::QueryMessage(const string& message, unsigned int type, long defaultVal)
{
  OutputMessage(message);
  return defaultVal;
}

long RteCallback::ShowMessageBox(const string& title, const string& message, unsigned int type, long defaultVal)
{
  OutputMessage(message);
  return defaultVal;
}

RteCallback* RteCallback::GetGlobal()
{
  if(theGlobalCallback) {
    return theGlobalCallback;
  }
  static RteCallback nullCallback;
  return &nullCallback;
}

void RteCallback::SetGlobal(RteCallback* callback)
{
  theGlobalCallback = callback;
}

string RteCallback::ExpandString(const string& str) {

  const RteKernel* kernel = GetRteKernel();
  if (!kernel) {
    return RteUtils::EMPTY_STRING;
  }

  const auto activeProject = kernel->GetActiveProject();
  if (!activeProject) {
    return RteUtils::EMPTY_STRING;
  }
  const auto activeTarget = kernel->GetActiveTarget();
  if (!activeTarget) {
    return RteUtils::EMPTY_STRING;
  }

  const string& prjPath(activeProject->GetProjectPath());
  const string& prjPathFile(prjPath + activeProject->GetName() + ".cprj");
  const string& packPath(activeTarget->GetDevicePackage()->GetAbsolutePackagePath());
  const string& deviceName(activeTarget->GetDeviceName());

  if (prjPath.empty() || prjPathFile.empty() || packPath.empty() || deviceName.empty()) {
    return RteUtils::EMPTY_STRING;
  }

  const string& boardName = activeTarget->GetAttribute("Bname");

  string res(str);
  RteUtils::ReplaceAll(res, "$P", prjPath);
  RteUtils::ReplaceAll(res, "#P", prjPathFile);
  RteUtils::ReplaceAll(res, "$S", packPath);
  RteUtils::ReplaceAll(res, "$D", deviceName);
  RteUtils::ReplaceAll(res, "$B", boardName);

  return res;
}

// end of RteCallback.cpp
